@@ -32,6 +32,7 @@
 #include <QLibraryInfo>
 #include <QTranslator>
 #include <QLocale>
+#include <QCoreApplication>
 
 #include <QSessionManager>
 
@@ -59,8 +60,10 @@ const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 
 #if QT_VERSION < QT_VERSION_CHECK(5, 0, 0)
 #define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt4/plugins"
-#else
+#elif QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 #define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt5/plugins"
+#else
+#define CONFIG_PLUGINSDIR CONFIG_LIBDIR "/qt6/plugins"
 #endif
 
 
@@ -127,7 +130,11 @@ qjackctlApplication::qjackctlApplication ( int& argc, char **argv )
 		if (m_pMyTranslator->load(sLocName, sLocPath)) {
 			QApplication::installTranslator(m_pMyTranslator);
 		} else {
+#ifndef _WIN32
 			sLocPath = CONFIG_DATADIR "/qjackctl/translations";
+#else
+			sLocPath = QCoreApplication::applicationDirPath() + "/translations";
+#endif
 			if (m_pMyTranslator->load(sLocName, sLocPath)) {
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
