@@ -1,7 +1,7 @@
 // qjackctlSessionForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2021, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -19,12 +19,9 @@
 
 *****************************************************************************/
 
-#include "qjackctlAbout.h"
 #include "qjackctlSessionForm.h"
 #include "qjackctlSession.h"
 
-#include "qjackctlSetup.h"
-
 #include "qjackctlMainForm.h"
 
 #include <QMenu>
