@@ -832,7 +832,7 @@ void qjackctlSetupForm::setCurrentPreset ( const qjackctlPreset& preset )
 			? QString::number(preset.iTimeout)
 			: sDefName);
 	setComboBoxCurrentData(m_ui.ClockSourceComboBox,
-		uint(preset.uClockSource));
+		QVariant::fromValue<uchar> (preset.ucClockSource));
 	setComboBoxCurrentText(m_ui.InDeviceComboBox,
 		preset.sInDevice.isEmpty()
 			? sDefName
@@ -911,12 +911,12 @@ bool qjackctlSetupForm::getCurrentPreset ( qjackctlPreset& preset )
 	if (preset.sOutDevice == sDefName)
 		preset.sOutDevice.clear();
 
-	preset.uClockSource = 0;
+	preset.ucClockSource = 0;
 	int iIndex = m_ui.ClockSourceComboBox->currentIndex();
 	if (iIndex >= 0)
-		preset.uClockSource = m_ui.ClockSourceComboBox->itemData(iIndex).toUInt();
+		preset.ucClockSource = m_ui.ClockSourceComboBox->itemData(iIndex).value<uchar> ();
 
-	preset.ucSelfConnectMode = ' ';
+	preset.ucSelfConnectMode = 0;
 	iIndex = m_ui.SelfConnectModeComboBox->currentIndex();
 	if (iIndex >= 0)
 		preset.ucSelfConnectMode = m_ui.SelfConnectModeComboBox->itemData(iIndex).value<uchar> ();
@@ -1186,13 +1186,13 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	const bool bJackDBus  = false;
 #endif
 
-	m_ui.SyncCheckBox->setEnabled(bJackDBus);
+//	m_ui.SyncCheckBox->setEnabled(bJackDBus);
 
-	m_ui.ClockSourceTextLabel->setEnabled(bJackDBus);
-	m_ui.ClockSourceComboBox->setEnabled(bJackDBus);
+//	m_ui.ClockSourceTextLabel->setEnabled(bJackDBus);
+//	m_ui.ClockSourceComboBox->setEnabled(bJackDBus);
 
-	m_ui.SelfConnectModeTextLabel->setEnabled(bJackDBus);
-	m_ui.SelfConnectModeComboBox->setEnabled(bJackDBus);
+//	m_ui.SelfConnectModeTextLabel->setEnabled(bJackDBus);
+//	m_ui.SelfConnectModeComboBox->setEnabled(bJackDBus);
 
 	m_ui.NoMemLockCheckBox->setEnabled(!bCoreaudio && !bJackDBus);
 	m_ui.UnlockMemCheckBox->setEnabled(!bCoreaudio && !bJackDBus
@@ -1223,7 +1223,7 @@ void qjackctlSetupForm::changeDriverUpdate ( const QString& sDriver, bool bUpdat
 	m_ui.PeriodsTextLabel->setEnabled(bAlsa || bSun || bOss || bFirewire);
 	m_ui.PeriodsSpinBox->setEnabled(bAlsa || bSun || bOss || bFirewire);
 
-	if (bUpdate && (bFirewire) && m_ui.PeriodsSpinBox->value() < 3)
+	if (bUpdate && bFirewire && m_ui.PeriodsSpinBox->value() < 3)
 		m_ui.PeriodsSpinBox->setValue(3);
 
 	m_ui.WordLengthTextLabel->setEnabled((bSun || bOss) && !bJackDBus);
