@@ -1,7 +1,7 @@
 // qjackctlSystemTray.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2017, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2019, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -25,7 +25,7 @@
 #include <QBitmap>
 #include <QPainter>
 
-#if QT_VERSION < 0x040500
+#if QT_VERSION < QT_VERSION_CHECK(4, 5, 0)
 namespace Qt {
 const WindowFlags WindowCloseButtonHint = WindowFlags(0x08000000);
 }
@@ -47,13 +47,6 @@ qjackctlSystemTray::qjackctlSystemTray ( QWidget *pParent )
 		QSystemTrayIcon::setToolTip(pParent->windowTitle());
 	}
 
-	// Set proper context menu, even though it's empty...
-	QSystemTrayIcon::setContextMenu(&m_menu);
-
-	QObject::connect(&m_menu,
-		SIGNAL(aboutToShow()),
-		SLOT(contextMenuRequested()));
-
 	QObject::connect(this,
 		SIGNAL(activated(QSystemTrayIcon::ActivationReason)),
 		SLOT(activated(QSystemTrayIcon::ActivationReason)));
@@ -73,11 +66,6 @@ void qjackctlSystemTray::close (void)
 void qjackctlSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 {
 	switch (reason) {
-#if 0
-	case QSystemTrayIcon::Context:
-		contextMenuRequested();
-		break;
-#endif
 	case QSystemTrayIcon::Trigger:
 		emit clicked();
 		break;
@@ -94,16 +82,6 @@ void qjackctlSystemTray::activated ( QSystemTrayIcon::ActivationReason reason )
 }
 
 
-void qjackctlSystemTray::contextMenuRequested (void)
-{
-	// Don't show dummy menu box, ever...
-	if (qobject_cast<QMenu *> (sender()) == &m_menu)
-		m_menu.hide();
-
-	emit contextMenuRequested(QCursor::pos());
-}
-
-
 // Default destructor.
 qjackctlSystemTray::~qjackctlSystemTray (void)
 {
